@@ -3,6 +3,7 @@
 SystemProfiles::SystemProfiles(QObject *parent) :
     QObject(parent)
 {
+    profile_track_add_profile_cb(profileChanged_cb, this, NULL);
 }
 
 QStringList SystemProfiles::profilesList()
@@ -34,3 +35,9 @@ void SystemProfiles::setProfile(QString profileName)
     Q_UNUSED(profileName)
 #endif
 }
+
+void SystemProfiles::profileChanged_cb(const char *profile, void *user_data)
+{
+    //qDebug() << "profileChanged_cb:" << profile;
+    emit static_cast<SystemProfiles*>(user_data)->profileChanged(QString::fromUtf8(profile));
+}
