@@ -241,6 +241,8 @@ LsWidget* LockScreen::createWidget(QString type, QString name)
         return new LsRadioMode(name);
     else if (type == "Bluetooth")
         return new LsBluetooth(name);
+    else if (type == "Profile")
+        return new LsProfile(name);
     return NULL;
 }
 
