@@ -32,10 +32,16 @@ void LsMediaMetadata::paint(QPainter *painter, const QStyleOptionGraphicsItem* o
     if (title.isEmpty())
         title = tr("Unknown title");
 
+    QFontMetrics tfm(m_TitleFont);
+    title = tfm.elidedText(title, Qt::ElideRight, option->exposedRect.width());
+
     QString artist = m_Metadata.value(SYSTEM_PLAYER_SONG_ARTIST).toString();
     if (artist.isEmpty())
         artist = tr("Unknown artist");
 
+    QFontMetrics afm(m_ArtistFont);
+    artist = afm.elidedText(artist, Qt::ElideRight, option->exposedRect.width());
+
     QRectF rect(boundingRect());
 
     painter->setFont(m_TitleFont);
